/* Introductory note
This practical exercise allows you to compute some country and product group specific indicators of NTMs incidence as presented in module 2. 
The data needed for this practical exercise were originally built by the CEPII. 
This institute provides on its website different indicators measuring NTMs incidence (http://www.cepii.fr/cepii/fr/bdd_modele/presentation.asp?id=28). 
These indicators are based on the TNT NTM data (http://unctad.org/en/Pages/DITC/Trade-Analysis/Non-Tariff-Measures/NTMs-TNT.aspx). 
Download the two files NTM-MAP Country.dta and NTM-MAP HS-Section.dta from the course website. 
The first file reports the data at the country level, while in the second one they are at the country and HS section levels. 
The sample includes 63 countries, of which 24 European countries, and deals with the five categories of NTMs defined 
in the TNT classification (SPS, TBT, pre-shipment inspections, price control, and quantity control measures, cf. Figure 4).
*/


/*Before opening the dataset you may want to change the default directory that is the directory STATA will use unless another directory is specified. We created a primary folder called 
STATA_NTM (c:/STATA_NTM) and secondary ones called application1 application 2 application3. 
We then copied all files that are needed to run the application (data files and do-files) into these folders. To change the default directory just run*/

cd c:/STATA_NTM/Application1

/*If you want to save the output of your session you must open a so-called log file */
log using application_1.log, replace /*it is in a text format*/


use NTM-MAP_Country.dta, clear

* If you had not changed the default directory the right command would be 
* use c:/ STATA_NTM/ NTM-MAP_Country.dta, clear


* Average all European countries
gen EU = 1 if isor == "AUT" | isor == "BEL" |isor == "CYP" | isor == "CZE" | isor == "DEU" | isor == "DNK" | isor == "ESP" | isor == "EST" | isor == "FIN" | isor == "FRA" | isor == "GBR" | isor == "GRC" | isor == "HUN" | isor == "IRL" | isor == "ITA" | isor == "LTU" | isor == "LUX" | isor =="LVA" | isor=="NLD" | isor == "POL" |isor=="PRT" | isor=="SVK" | isor == "SVN" | isor == "SWE"

replace isor = "EUR" if EU == 1

collapse HSline Num* Pres* Cov* Freq* , by(isor)

* Define continent 

gen continent = "Lat_America" if isor == "ARG" | isor == "BOL" | isor == "BRA" | isor == "CHL" | isor == "COL" | isor == "CRI" | isor == "ECU" | isor == "GTM" | isor == "MEX" | isor == "PER" | isor == "PRY" | isor =="VEN" | isor == "URY"

replace continent = "Africa" if isor == "BDI" | isor == "BFA" | isor == "CIV" | isor == "GIN" | isor == "KEN" | isor == "MDG" | isor == "MUS" | isor == "SEN" | isor == "TZA" |isor == "UGA" | isor == "ZAF"

replace continent = "Asia" if isor == "BGD" | isor == "IND" | isor == "LKA" | isor == "NPL" | isor == "PAK" | isor == "CHN" | isor == "IDN" |isor == "KHM" | isor == "LAO" | isor ==" PHL"

replace continent = "MENA" if isor == "EGY" | isor == "LBN" | isor == "MAR" |isor == "SYR" | isor == "TUN"
replace continent = "Dvlped" if isor == "EUR" | isor == "JPN"

save temp_NTM_country, replace

use NTM-MAP_HS-Section.dta, clear

* Sections' label
gen Section_label = "Live animals" if Section == 1
replace Section_label = "Vegetable products" if Section == 2
replace Section_label = "Fats and oils" if Section == 3
replace Section_label = "Processed food" if Section == 4
replace Section_label = "Mineral products" if Section == 5
replace Section_label = "Chemicals" if Section == 6
replace Section_label = "Rubber and plastics" if Section == 7
replace Section_label = "Rawhide and skins" if Section == 8
replace Section_label = "Wood" if Section == 9
replace Section_label = "Paper" if Section == 10
replace Section_label = "Textile" if Section == 11
replace Section_label = "Footwear" if Section == 12
replace Section_label = "Stone and Cement" if Section == 13
replace Section_label = "Pearls" if Section == 14
replace Section_label = "Base metals" if Section == 15
replace Section_label = "Machinery and electrical equipment" if Section == 16
replace Section_label = "Motor vehicles" if Section == 17
replace Section_label = "Optical and medical instruments" if Section == 18
replace Section_label = "Arms and ammunition" if Section == 19
replace Section_label = "Miscellaneous" if Section == 20
replace Section_label = "Works of Art" if Section == 21

* Average all EU countries
gen EU = 1 if isor == "AUT" | isor == "BEL" | isor == "CYP" | isor == "CZE" | isor == "DEU" | isor == "DNK" | isor == "ESP" | isor == "EST" | isor == "FIN" | isor == "FRA" | isor == "GBR" | isor == "GRC" | isor == "HUN" |isor == "IRL" | isor == "ITA" | isor == "LTU" | isor == "LUX" | isor == "LVA" | isor == "NLD" | isor == "POL" | isor == "PRT" |isor == "SVK" | isor == "SVN" | isor == "SWE"

replace isor = "EUR" if EU == 1
collapse Num* Pres* Cov* Freq* , by(isor Section Section_label)
 
* Define continent 
gen continent = "Lat_America" if isor == "ARG" | isor == "BOL" | isor == "BRA" | isor == "CHL" | isor == "COL" | isor == "CRI" | isor == "ECU"| isor == "GTM"| isor == "MEX" | isor == "PER" | isor == "PRY" | isor == "VEN" | isor == "URY"

replace continent = "Africa" if isor == "BDI" | isor == "BFA" | isor == "CIV" | isor == "GIN" | isor == "KEN" | isor == "MDG" | isor == "MUS" | isor == "SEN" | isor == "TZA" | isor == "UGA" | isor == "ZAF"

replace continent = "Asia" if isor == "BGD" | isor == "IND" | isor == "LKA" | isor =="NPL" | isor == "PAK" | isor == "CHN" | isor == "IDN" | isor == "KHM" | isor == "LAO" | isor =="PHL"

replace continent = "MENA" if isor == "EGY" | isor == "LBN"| isor == "MAR" | isor == "SYR" | isor == "TUN"
replace continent = "Dvlped" if isor == "EUR" | isor == "JPN"

save temp_NTM_section, replace

use temp_NTM_country, clear

collapse FreqA-FreqE CovA-CovE NumA-NumE

graph bar Freq*, legend(label(1 "SPS") label(2 "TBT") label(3 "Pre-shipment")label(4 "Price control") label(5 "Quantity control")) title("Frequency Index, by broad type of NTMs") ytitle("Value")

/*In order to export your graph in a format that is usable in a text editor use the graph export command*/
graph export FREQ_index_all_NTM.wmf /*it is here exported in windows metafile format

graph bar Cov*, legend(label(1 "SPS") label(2 "TBT") label(3 "Pre-shipment")label(4 "Price control") label(5 "Quantity control")) title("Coverage Ratio, by broad type of NTMs") ytitle("Value")

graph export COV_ratio_all_NTM.wmf 

use temp_NTM_country, clear

collapse FreqNTM CovNTM NumNTM, by(continent)

graph bar FreqNTM CovNTM, over(continent) legend(label(1 "Freq. Index (all NTMs)") label(2 "Coverage ratio (all NTMs)")) title("Frequency Index and Coverage Ratio, by continent") ytitle("Value")

graph export COV_ratio_ALL_CONT.wmf 

graph bar NumNTM, over(continent) legend(label(1 "Prevalence Ratio (all NTMs)")) title("Prevalence Ratio, by continent") ytitle("Value")

graph export PREV_ratio__ALL_CONT.wmf

use temp_NTM_country, clear

graph bar FreqNTM CovNTM if continent == "Africa", over(isor) legend(label(1 "Freq. Index (all NTMs)") label(2 "Coverage ratio (all NTMs)")) title("Frequency Index and Coverage Ratio, by African country") ytitle("Value")

graph export FREQ_index_NTM_AFRI.wmf 

graph bar NumNTM if continent == "Africa", over(isor) legend(label(1 "Prevalence Ratio (all NTMs)")) title("Prevalence Ratio, by African country") ytitle("Value")

graph export PREV_ratio_NTM_AFRI.wmf 


use temp_NTM_country, replace
gen shr_NTM = PresNTM/HSline * 100
gen shr_SPS = PresA/HSline * 100
gen shr_TBT = PresB/HSline * 100
label var shr_NTM "Share of HS6 lines with at least one NTM (%)"
label var shr_SPS "Share of HS6 lines with at least one SPS (%)"
label var shr_TBT "Share of HS6 lines with at least one TBT (%)"
sort isor
edit isor shr_NTM
edit isor shr_NTM shr_SPS shr_TBT
sum shr_*


use temp_NTM_section, replace
collapse FreqNTM, by(Section Section_label)

edit Section Section_label FreqNTM
use temp_NTM_section, replace
collapse FreqNTM , by(Section Section_label continent)

reshape wide FreqNTM, i(Section Section_label) j(continent) string

rename FreqNTMAfrica Freq_Africa
rename FreqNTMAsia Freq_Asia
rename FreqNTMDvlped Freq_Dvlped
rename FreqNTMLat_America Freq_LatAmerica
rename FreqNTMMENA Freq_MENA

label var Freq_Africa "Freq. Index, Africa & all NTMs"
label var Freq_Asia "Freq. Index, Asia & all NTMs"
label var Freq_Dvlped "Freq. Index, Dvlped countries & all NTMs"
label var Freq_LatAmerica "Freq. Index, Latin America & all NTMs"
label var Freq_MENA "Freq. Index, MENA & all NTMs"

edit Section Section_label Freq*

/* you must close your log file at the end of the session*/
log close

